@@ -79,7 +79,6 @@ class KTEXTEDITOR_EXPORT ViewPrivate final : public KTextEditor::View
     friend class KTextEditor::View;
     friend class ::KateViewInternal;
     friend class ::KateIconBorder;
-    friend class ::KateTextPreview;
     friend MulticursorTest;
 
 public:
@@ -180,11 +179,10 @@ public:
     QPoint cursorToCoordinate(KTextEditor::Cursor cursor) const override;
 
     KTextEditor::Cursor coordinatesToCursor(const QPoint &coord) const override;
+    [[nodiscard]] KTextEditor::Cursor coordinatesToCursor(QPoint coords, CoordinatesToCursorFlags flags) const;
 
     QPoint cursorPositionCoordinates() const override;
 
-    bool setCursorPositionVisual(const KTextEditor::Cursor position);
-
     QScrollBar *verticalScrollBar() const override;
     QScrollBar *horizontalScrollBar() const override;
 
@@ -300,7 +298,7 @@ private:
 
     // Internal
 public:
-    bool setCursorPositionInternal(const KTextEditor::Cursor position, uint tabwidth = 1, bool calledExternally = false);
+    bool setCursorPositionInternal(const KTextEditor::Cursor position, bool calledExternally = false);
 
     //
     // KTextEditor::ConfigInterface
@@ -313,7 +311,7 @@ public:
 public:
     /**
      * Try to fold an unfolded range starting at @p line
-     * @return the new folded range on success, otherwise an unvalid range
+     * @return the new folded range on success, otherwise an invalid range
      */
     KTextEditor::Range foldLine(int line);
 
@@ -364,7 +362,10 @@ public Q_SLOTS:
 
 public:
     KateCompletionWidget *completionWidget() const;
-    mutable KateCompletionWidget *m_completionWidget;
+
+    // we re-parent this, use a QPointer to be sure we know if that is still alive
+    mutable QPointer<KateCompletionWidget> m_completionWidget;
+
     void sendCompletionExecuted(const KTextEditor::Cursor position, KTextEditor::CodeCompletionModel *model, const QModelIndex &index);
     void sendCompletionAborted();
 
@@ -432,8 +433,6 @@ public:
     bool blockSelection() const override;
     KTextEditor::Range selectionRange() const override;
 
-    static void blockFix(KTextEditor::Range &range);
-
     //
     // Arbitrary Syntax HL + Action extensions
     //
@@ -835,6 +834,15 @@ public:
 
     void exportHtmlToFile(const QString &file);
 
+    // should the current line be highlighted during rendering?
+    bool isHighlightCurrentLineActive() const;
+
+    // should the cursor be painted during rendering?
+    bool isCursorVisible() const;
+
+    // should the bracket match be highlighted during rendering?
+    bool isBracketMatchHighlightActive() const;
+
 private Q_SLOTS:
     void slotDocumentReloaded();
     void slotDocumentAboutToReload();
@@ -932,7 +940,12 @@ private Q_SLOTS:
      * Configuration
      */
 public:
-    inline KateViewConfig *config()
+    KateViewConfig *config()
+    {
+        return m_config;
+    }
+
+    const KateViewConfig *config() const
     {
         return m_config;
     }
@@ -1168,7 +1181,7 @@ public:
     }
 
     /**
-     * Toogle status bar, e.g. create or remove it
+     * Toggle status bar, e.g. create or remove it
      */
     void toggleStatusBar();
 
